.. _credits:

Credits
-------

The main development has been done by Josef Heinen who currently maintains
the software. There is a number of active developers - special thanks to
Florian Rhiem and Christian Felder who have made valuable contributions.
Major contributors include the following (in alphabetical order):

**Fabian Beule**

  implemented the GR3 surface function

**Marcel Dück**

  wrote the Java code and the iGR iOS App

**Christian Felder**

  provided the qtgr module, the setup.py script and the GKS iOS App. As part of a collaboration there are plans to integrate the GR framework into `NICOS <http://cdn.frm2.tum.de/fileadmin/stuff/services/ITServices/nicos-2.0/dirhtml/>`_ (a network-based control system completely written in Python) as a replacement for PyQwt.

**Marvin Goblet**

  developed the the initial GKSTerm implementation

**Ingo Heimbach**

  implemented the GKS wxWidgets plugin

**David Knodt**

  wrote the video converter routines

**Robert Nesselrath**

  provided the glgr application

**Florian Rhiem**

  designed and implemented *GR3*

**Elmar Westphal**

  wrote the gr_textex routine

**Jörg Winkler**

  implemented the GKS OpenGL device driver

